import type { TokenType } from '../../types'
import type { RNTokenStyle } from '../../utils/style-transformer'
import React from 'react'
import { Platform, StyleSheet, Text, View } from 'react-native'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

const styles = StyleSheet.create({
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  token: {
    includeFontPadding: false,
  },
})

interface SyntaxLineProps {
  line: TokenType[]
  fontSize?: number
  isLastLine?: boolean
  themeStyles: {
    backgroundColor: string
    defaultColor: string
    styles: Record<string, RNTokenStyle>
  }
}

function SyntaxLine({ line, fontSize = 14, isLastLine = false, themeStyles }: SyntaxLineProps) {
  const lineHeight = Math.floor(fontSize * 1.5)

  return (
    <View
      style={[
        styles.lineContainer,
        {
          minHeight: lineHeight,
          paddingBottom: !isLastLine ? 4 : 0,
        },
      ]}
    >
      {line.map((token, tokenIndex) => {
        const content = token.content.replace(/ /g, '\u00A0')
        // Use converted theme styles
        const tokenStyle = token.color ? { color: token.color } : { color: themeStyles.defaultColor }

        return (
          <Text
            key={`${tokenIndex}-${content.slice(0, 8)}`}
            style={[
              styles.token,
              {
                ...tokenStyle,
                fontFamily: monospaceFont,
                fontSize,
                fontStyle: token.fontStyle as 'normal' | 'italic',
                fontWeight: token.fontWeight as 'normal' | 'bold',
                lineHeight,
                height: lineHeight,
                textAlignVertical: 'center',
                ...(Platform.OS === 'ios'
                  ? {
                      paddingTop: 2,
                    }
                  : {}),
              },
            ]}
          >
            {content}
          </Text>
        )
      })}
    </View>
  )
}

export default SyntaxLine
